@@ -32,6 +32,9 @@ Packet payload without preamble (203 bits):
     -----------------------------------------------------------------------------
     ed ee 46 ff ff ff ef 9f ff 8b 7d eb ff 12 11 b9 00 00 00 10 60 00 74 82 14 00 00 00 (Rain Gauge)
     e9 ee 46 ff ff ff ef 99 ff 8b 8b eb ff 16 11 b9 00 00 00 10 66 00 74 74 14 00 00 00 (Rain Gauge)
+    ec 3d 45 ff ff ff ef 66 ff 8e bf fe ff 13 c2 ba 00 00 00 10 99 00 71 40 01 00 00 00 (Rain Gauge)
+    eb 28 c4 ff ff ff ef ea fe 8e ff ff ff 14 d7 3b 00 00 00 10 15 01 71 00 00 00 00 00 (Rain Gauge, immediately after reset)
+    e9 28 44 ff ff ff ef 6a ff 8e fe ff ff 16 d7 bb 00 00 00 10 95 00 71 01 00 00 00 00 (same Rain Gauge, 90 min after reset)
     ee 93 7f f7 bf fb ef 9e fe ae bf ff ff 11 6c 80 08 40 04 10 61 01 51 40 00 00
     ed 93 7f ff 0f ff ef b8 fe 7d bf ff ff 12 6c 80 00 f0 00 10 47 01 82 40 00 00
     eb 93 7f eb 9f ee ef fc fc d6 bf ff ff 14 6c 80 14 60 11 10 03 03 29 40 00 00
@@ -42,22 +45,23 @@ Packet payload without preamble (203 bits):
     ef a1 ff ff 1f ff ef dc ff de df ff 7f 10 5e 00 00 e0 00 10 23 00 21 20 00 80 00 00 (low batt +ve temp)
     ed a1 ff ff 1f ff ef 8f ff d6 df ff 77 12 5e 00 00 e0 00 10 70 00 29 20 00 88 00 00 (low batt -ve temp -7.0C)
     ec 91 ff ff 1f fb ef e7 fe ad ed ff f7 13 6e 00 00 e0 04 10 18 01 52 12 00 08 00 00 (good batt -ve temp)
+    ed a8 7f ff 3f ff ef f0 ff f0 fb ff ff 12 57 80 00 c0 00 10 0f 00 0f 04 00 00 00 00 (bad temp /hum data)
     CC CC CC CC CC CC CC CC CC CC CC CC CC uu II sS GG DG WW  W TT  T HH RR RR Bt
                                               G-MSB ^     ^ W-MSB  (strange but consistent order)
 
-- C = Check, inverted data of 13 byte further
+- C = check, inverted data of 13 byte further
 - uu = checksum (number/count of set bits within bytes 14-25)
 - I = station ID (maybe)
+- s = startup, MSb is 0b0 after power-on/reset and 0b1 after 1 hour
+- S = sensor type, 0x9/0xA/0xB for Bresser Professional Rain Gauge
 - G = wind gust in 1/10 m/s, normal binary coded, GGxG = 0x76D1 => 0x0176 = 256 + 118 = 374 => 37.4 m/s.  MSB is out of sequence.
 - D = wind direction 0..F = N..NNE..E..S..W..NNW
 - W = wind speed in 1/10 m/s, BCD coded, WWxW = 0x7512 => 0x0275 = 275 => 27.5 m/s. MSB is out of sequence.
-- T = temperature in 1/10 °C, BCD coded, TTxT = 1203 => 31.2 °C
+- T = temperature in 1/10 °C, BCD coded, TTxT = 1203 => 31.2 °C, 0xf on error
 - t = temperature sign, minus if unequal 0
-- H = humidity in percent, BCD coded, HH = 23 => 23 %
+- H = humidity in percent, BCD coded, HH = 23 => 23 %, 0xf on error
 - R = rain in mm, BCD coded, RRRR = 1203 => 031.2 mm
-- B = Battery. 0=Ok, 8=Low.
-- s = startup, 0 after power-on/reset / 8 after 1 hour
-- S = sensor type, only low nibble used, 0x9 for Bresser Professional Rain Gauge
+- B = battery, 0=Ok, 8=Low
 */
 
 static int bresser_5in1_decode(r_device *decoder, bitbuffer_t *bitbuffer)
@@ -106,11 +110,13 @@ static int bresser_5in1_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 
     sensor_id = msg[14];
 
+    int temp_ok = (msg[20] & 0x0f) <= 9; // BCD, 0x0f on error
     int temp_raw = (msg[20] & 0x0f) + ((msg[20] & 0xf0) >> 4) * 10 + (msg[21] &0x0f) * 100;
     if (msg[25] & 0x0f)
         temp_raw = -temp_raw;
     float temperature = temp_raw * 0.1f;
 
+    int humidity_ok = (msg[22] & 0x0f) <= 9; // BCD, 0x0f on error
     int humidity = (msg[22] & 0x0f) + ((msg[22] & 0xf0) >> 4) * 10;
 
     float wind_direction_deg = ((msg[17] & 0xf0) >> 4) * 22.5f;
@@ -126,16 +132,18 @@ static int bresser_5in1_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 
     int battery_low = (msg[25] & 0x80);
 
+    int sensor_type = (msg[15] & 0x7f);
+
     /* check if the message is from a Bresser Professional Rain Gauge */
-    if ((msg[15] & 0xF) == 0x9) {
+    if ((sensor_type >= 0x39) && (sensor_type <= 0x3b)) {
         // rescale the rain sensor readings
-        rain = rain * 2.5;
+        rain = rain * 2.5f;
         /* clang-format off */
         data = data_make(
                 "model",            "",             DATA_STRING, "Bresser-ProRainGauge",
                 "id",               "",             DATA_INT,    sensor_id,
                 "battery_ok",       "Battery",      DATA_INT,    !battery_low,
-                "temperature_C",    "Temperature",  DATA_FORMAT, "%.1f C",      DATA_DOUBLE, temperature,
+                "temperature_C",    "Temperature",  DATA_COND,   temp_ok,       DATA_FORMAT, "%.1f C", DATA_DOUBLE, temperature,
                 "rain_mm",          "Rain",         DATA_FORMAT, "%.1f mm",     DATA_DOUBLE, rain,
                 "mic",              "Integrity",    DATA_STRING, "CHECKSUM",
                 NULL);
@@ -147,8 +155,8 @@ static int bresser_5in1_decode(r_device *decoder, bitbuffer_t *bitbuffer)
                 "model",            "",             DATA_STRING, "Bresser-5in1",
                 "id",               "",             DATA_INT,    sensor_id,
                 "battery_ok",       "Battery",      DATA_INT,    !battery_low,
-                "temperature_C",    "Temperature",  DATA_FORMAT, "%.1f C",      DATA_DOUBLE, temperature,
-                "humidity",         "Humidity",     DATA_INT,    humidity,
+                "temperature_C",    "Temperature",  DATA_COND,   temp_ok,       DATA_FORMAT, "%.1f C", DATA_DOUBLE, temperature,
+                "humidity",         "Humidity",     DATA_COND,   humidity_ok,   DATA_INT,    humidity,
                 "wind_max_m_s",     "Wind Gust",    DATA_FORMAT, "%.1f m/s",    DATA_DOUBLE, wind_gust,
                 "wind_avg_m_s",     "Wind Speed",   DATA_FORMAT, "%.1f m/s",    DATA_DOUBLE, wind_avg,
                 "wind_dir_deg",     "Direction",    DATA_FORMAT, "%.1f",        DATA_DOUBLE, wind_direction_deg,
