@@ -14,9 +14,9 @@
 #include "fatal.h"
 #include <stdlib.h>
 
-static inline int bit(const uint8_t *bytes, unsigned bit)
+static inline int bit(const uint8_t *bytes, unsigned b)
 {
-    return bytes[bit >> 3] >> (7 - (bit & 7)) & 1;
+    return bytes[b >> 3] >> (7 - (b & 7)) & 1;
 }
 
 /// extract all mask bits skipping unmasked bits of a number up to 32/64 bits
@@ -296,11 +296,12 @@ static int flex_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         print_row_bytes(row_bytes, bitbuffer->bb[i], bitbuffer->bits_per_row[i]);
 
         /* clang-format off */
-        row_data[i] = data_make(
+        data = data_make(
                 "len", "", DATA_INT, bitbuffer->bits_per_row[i],
                 "data", "", DATA_STRING, row_bytes,
                 NULL);
         /* clang-format on */
+        row_data[i] = data;
 
         // add a data line for each getter
         render_getters(row_data[i], bitbuffer->bb[i], params);
