@@ -37,7 +37,7 @@ static int generic_motion_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         // strictly validate package as there is no checksum
         if ((bitbuffer->bits_per_row[i] != 20)
                 || ((b[1] == 0) && (b[2] == 0))
-                || ((b[1] == 0xff) && (b[2] == 0xff))
+                || ((b[1] == 0xff) && (b[2] == 0xf0))
                 || bitbuffer_count_repeats(bitbuffer, i, 0) < 3)
             continue; // DECODE_ABORT_EARLY
 
