@@ -81,7 +81,7 @@ static int megacode_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     return 1;
 }
 
-static char *output_fields[] = {
+static char const *const output_fields[] = {
         "model",
         "id",
         "raw",
@@ -90,7 +90,7 @@ static char *output_fields[] = {
         NULL,
 };
 
-r_device megacode = {
+r_device const megacode = {
         .name        = "Linear Megacode Garage/Gate Remotes",
         .modulation  = OOK_PULSE_PCM,
         .short_width = 1000,
