@@ -1,5 +1,5 @@
 /** @file
-    Somfy io-homecontrol.
+    Somfy io-homecontrol devices.
 
     Copyright (C) 2021 Christian W. Zuckschwerdt <zany@triq.net>
 
@@ -9,6 +9,8 @@
     (at your option) any later version.
 */
 
+#include "decoder.h"
+
 /**
 Somfy io-homecontrol devices.
 
@@ -89,58 +91,104 @@ Example packets:
 
 */
 
-#include "decoder.h"
-
 static int somfy_iohc_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 {
     uint8_t const preamble_pattern[] = {0x57, 0xfd, 0x99};
 
-    uint8_t b[19 + 15]; // 19 byte + up 15 byte payload
+    uint8_t b[1 + 31 + 2]; // Length, payload, CRC
 
     if (bitbuffer->num_rows != 1)
         return DECODE_ABORT_EARLY;
 
     unsigned offset = bitbuffer_search(bitbuffer, 0, 0, preamble_pattern, 24) + 24;
-    if (offset + 19 * 10 >= bitbuffer->bits_per_row[0])
+    if (offset >= bitbuffer->bits_per_row[0])
         return DECODE_ABORT_EARLY;
+    int num_bits = bitbuffer->bits_per_row[0] - offset;
 
-    unsigned num_bits = bitbuffer->bits_per_row[0] - offset;
-    num_bits = MIN(num_bits, sizeof (b) * 8);
+    num_bits = MIN((size_t)num_bits, sizeof (b) * 8);
 
     int len = extract_bytes_uart(bitbuffer->bb[0], offset, num_bits, b);
-    if (len < 19)
+    if (len < 11)
         return DECODE_ABORT_LENGTH;
 
-    if ((b[0] & 0xf0) != 0xf0)
-        return DECODE_ABORT_EARLY;
-
-    int msg_len = b[0] & 0xf; // should be 6 or 8
-    if (len < 19 + msg_len)
+    // Mandatory fields
+    // Control byte 1
+    // end_flag : 1
+    // start_flag : 1
+    // protocol_mode : 1
+    // frame_length : 5
+    int msg_len = b[0] & 0x1f;
+    if (len < msg_len + 3)
         return DECODE_ABORT_LENGTH;
+    if (msg_len < 8)
+        return DECODE_ABORT_LENGTH;
+    len = msg_len + 3;
+
+    int msg_end_flag      = (b[0] & 0x80) >> 7;
+    int msg_start_flag    = (b[0] & 0x40) >> 6;
+    int msg_protocol_mode = (b[0] & 0x20) >> 5;
+
+    // Control byte 2
+    // use_beacon : 1
+    // is_routed : 1
+    // low_power_mode : 1
+    // protocol_version : 3
+    int msg_use_beacon       = (b[1] & 0x80) >> 7;
+    int msg_is_routed        = (b[1] & 0x40) >> 6;
+    int msg_low_power_mode   = (b[1] & 0x20) >> 5;
+    int msg_protocol_version = b[1] & 0x03;
+
+    // Addresses
+    // dst_addr : 24
+    // src_addr : 24
+    int msg_dst_addr = (b[2] << 16) | (b[3] << 8) | b[4];
+    int msg_src_addr = (b[5] << 16) | (b[6] << 8) | b[7];
+
+    // Command ID
+    // cmd_id : 8
+    int msg_cmd_id = b[8];
+
+    // optional fields
+    int msg_seq_nr = 0;
+    char msg_mac[13] = {0};
+
+    char msg_data[31 * 2 + 1]; // variable length, converted to hex string
+    unsigned int data_length = msg_len - 8;
+    if (msg_protocol_mode == 0 || data_length < 8) {
+        bitrow_snprint(&b[9], data_length * 8, msg_data, sizeof (msg_data));
+    } else {
+        data_length -= 8;
+        bitrow_snprint(&b[9], data_length * 8, msg_data, sizeof (msg_data));
+        msg_seq_nr = (b[9 + data_length] << 8) | b[9 + data_length + 1];
+        bitrow_snprint(&b[9 + data_length + 2], 6 * 8, msg_mac, sizeof msg_mac);
+    }
+
+    // crc : 16;
+    //int msg_crc = (b[len - 2] << 8) | b[len - 1];
 
     // calculate and verify checksum
     if (crc16lsb(b, len, 0x8408, 0x0000) != 0) // unreflected poly 0x1021
         return DECODE_FAIL_MIC;
-    decoder_logf_bitrow(decoder, 2, __func__, b, len * 8, "offset %u, num_bits %u, len %d, msg_len %d", offset, num_bits, len, msg_len);
 
-    int msg_type = (b[0]);
-    int dst_id   = ((unsigned)b[4] << 24) | (b[3] << 16) | (b[2] << 8) | (b[1]); // assume Little-Endian
-    int src_id   = ((unsigned)b[8] << 24) | (b[7] << 16) | (b[6] << 8) | (b[5]); // assume Little-Endian
-    int counter  = (b[len - 10] << 8) | (b[len - 9]);
-    char msg_str[15 * 2 + 1];
-    bitrow_snprint(&b[9], msg_len * 8, msg_str, 15 * 2 + 1);
-    char mac_str[13];
-    bitrow_snprint(&b[len - 8], 6 * 8, mac_str, 13);
+    decoder_logf_bitrow(decoder, 2, __func__, b, len * 8, "offset %u, num_bits %u, len %d, msg_len %d", offset, num_bits, len, msg_len);
 
     /* clang-format off */
     data_t *data = data_make(
             "model",            "",                 DATA_STRING, "Somfy-IOHC",
-            "id",               "",                 DATA_FORMAT, "%08x", DATA_INT, src_id,
-            "dst_id",           "Dest ID",          DATA_FORMAT, "%08x", DATA_INT, dst_id,
-            "msg_type",         "Msg type",         DATA_FORMAT, "%02x", DATA_INT, msg_type,
-            "msg",              "Message",          DATA_STRING, msg_str,
-            "counter",          "Counter",          DATA_INT,    counter,
-            "mac",              "MAC",              DATA_STRING, mac_str,
+            "id",               "Source",           DATA_FORMAT, "%06x", DATA_INT, msg_src_addr,
+            "dst_id",           "Target",           DATA_FORMAT, "%06x", DATA_INT, msg_dst_addr,
+            "msg_type",         "Command",          DATA_FORMAT, "%02x", DATA_INT, msg_cmd_id,
+            "msg",              "Message",          DATA_STRING, msg_data,
+            "mode",             "Mode",             DATA_STRING, msg_protocol_mode ? "One-way" : "Two-way",
+            "version",          "Version",          DATA_INT,    msg_protocol_version,
+            "counter",          "Counter",          DATA_COND, msg_protocol_mode == 1, DATA_INT,    msg_seq_nr,
+            "mac",              "MAC",              DATA_COND, msg_protocol_mode == 1, DATA_STRING, msg_mac,
+            "flag_end",         "End flag",         DATA_INT,    msg_end_flag,
+            "flag_start",       "Start flag",       DATA_INT,    msg_start_flag,
+            "flag_mode",        "Mode flag",        DATA_INT,    msg_protocol_mode,
+            "flag_beacon",      "Beacon flag",      DATA_INT,    msg_use_beacon,
+            "flag_routed",      "Routed flag",      DATA_INT,    msg_is_routed,
+            "flag_lpm",         "LPM flag",         DATA_INT,    msg_low_power_mode,
             "mic",              "Integrity",        DATA_STRING, "CRC",
             NULL);
     /* clang-format on */
@@ -149,20 +197,28 @@ static int somfy_iohc_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     return 1;
 }
 
-static char *output_fields[] = {
+static char const *const output_fields[] = {
         "model",
         "id",
         "dst_id",
         "msg_type",
         "msg",
+        "mode",
+        "version",
         "counter",
         "mac",
+        "flag_end",
+        "flag_start",
+        "flag_mode",
+        "flag_beacon",
+        "flag_routed",
+        "flag_lpm",
         "mic",
         NULL,
 };
 
 // rtl_433 -c 0 -R 0 -g 40 -X "n=uart,m=FSK_PCM,s=26,l=26,r=300,preamble={24}0x57fd99,decode_uart" -f 868.89M
-r_device somfy_iohc = {
+r_device const somfy_iohc = {
         .name        = "Somfy io-homecontrol",
         .modulation  = FSK_PULSE_PCM,
         .short_width = 26,
