@@ -95,7 +95,7 @@ static int tpms_ave_decode(r_device *decoder, bitbuffer_t *bitbuffer, unsigned r
             "model",            "Model",         DATA_STRING, "AVE",
             "type",             "Type",          DATA_STRING, "TPMS",
             "id",               "Id",            DATA_STRING, id_str,
-            "mode",             "Mode",          DATA_FORMAT, "M%i", DATA_INT, mode,
+            "mode",             "Mode",          DATA_FORMAT, "M%d", DATA_INT, mode,
             "pressure_kPa",     "Pressure",      DATA_FORMAT, "%.1f kPa", DATA_DOUBLE, pressure,
             "temperature_C",    "Temperature",   DATA_FORMAT, "%.0f C", DATA_DOUBLE, (double)temperature - 50.0,
             "battery_ok",       "Battery level", DATA_COND, battery_level < 6, DATA_DOUBLE, 1.0,
