@@ -74,7 +74,7 @@ static int tpms_truck_decode(r_device *decoder, bitbuffer_t *bitbuffer, unsigned
     int temperature = b[7];
 
     char id_str[4 * 2 + 1];
-    sprintf(id_str, "%08x", id);
+    snprintf(id_str, sizeof(id_str), "%08x", id);
 
     /* clang-format off */
     data_t *data = data_make(
@@ -114,7 +114,7 @@ static int tpms_truck_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     return events;
 }
 
-static char *output_fields[] = {
+static char const *const output_fields[] = {
         "model",
         "type",
         "id",
@@ -127,7 +127,7 @@ static char *output_fields[] = {
         NULL,
 };
 
-r_device tpms_truck = {
+r_device const tpms_truck = {
         .name        = "Unbranded SolarTPMS for trucks",
         .modulation  = FSK_PULSE_PCM,
         .short_width = 52,
