@@ -85,7 +85,7 @@ void pulse_data_print_vcd_header(FILE *file, uint32_t sample_rate)
         timescale = "1 us";
     else
         timescale = "100 ns";
-    chk_ret(fprintf(file, "$date %s $end\n", format_time_str(time_str, NULL, 0, 0)));
+    chk_ret(fprintf(file, "$date %s $end\n", usecs_time_str(time_str, NULL, 0, 0)));
     chk_ret(fprintf(file, "$version rtl_433 0.1.0 $end\n"));
     chk_ret(fprintf(file, "$comment Acquisition at %s Hz $end\n", nice_freq(sample_rate)));
     chk_ret(fprintf(file, "$timescale %s $end\n", timescale));
@@ -176,7 +176,7 @@ void pulse_data_print_pulse_header(FILE *file)
     chk_ret(fprintf(file, ";version 1\n"));
     chk_ret(fprintf(file, ";timescale 1us\n"));
     // chk_ret(fprintf(file, ";samplerate %u\n", data->sample_rate));
-    chk_ret(fprintf(file, ";created %s\n", format_time_str(time_str, NULL, 1, 0)));
+    chk_ret(fprintf(file, ";created %s\n", usecs_time_str(time_str, NULL, 1, 0)));
 }
 
 void pulse_data_dump(FILE *file, pulse_data_t const *data)
@@ -187,7 +187,7 @@ void pulse_data_dump(FILE *file, pulse_data_t const *data)
 
     char time_str[LOCAL_TIME_BUFLEN];
 
-    chk_ret(fprintf(file, ";received %s\n", format_time_str(time_str, NULL, 1, 0)));
+    chk_ret(fprintf(file, ";received %s\n", usecs_time_str(time_str, NULL, 1, 0)));
     if (data->fsk_f2_est) {
         chk_ret(fprintf(file, ";fsk %u pulses\n", data->num_pulses));
         chk_ret(fprintf(file, ";freq1 %.0f\n", data->freq1_hz));
